==> wasm4-impl-0.1.1.crate: wasm4-impl-0.1.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.1.1 (2022-01-17)

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 2 commits contributed to the release.
 - 2 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - fix crates' descriptions ([`2bed060`](https://github.com/ZetaNumbers/wasm4-rs/commit/2bed0608fe6d1f95412b53e4b2a100c6d9413898))
    - fix license ([`7e163bd`](https://github.com/ZetaNumbers/wasm4-rs/commit/7e163bdedd898202b4009fd19a79e286592174a0))
</details>

## 0.1.0 (2022-01-14)

### New Features

 - <csr-id-06dc6afedf6ea051c5927fd06f0b7fd84a6bb55b/> add `include_sprites!` macro

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 4 commits contributed to the release.
 - 3 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release wasm4-impl v0.1.0 ([`2031d7b`](https://github.com/ZetaNumbers/wasm4-rs/commit/2031d7b5dfe38b8a5394942e1777811e5c70812b))
    - update changelogs ([`a0f0eb4`](https://github.com/ZetaNumbers/wasm4-rs/commit/a0f0eb4c388e0b91a9edda291aa61f10e3388229))
    - bump versions ([`ac05404`](https://github.com/ZetaNumbers/wasm4-rs/commit/ac05404fc96f0089d40dd55f238da870f683526f))
    - add `include_sprites!` macro ([`06dc6af`](https://github.com/ZetaNumbers/wasm4-rs/commit/06dc6afedf6ea051c5927fd06f0b7fd84a6bb55b))
</details>

==> wasm4-impl-0.1.2.crate: wasm4-impl-0.1.2/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.1.2 (2022-01-17)

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 1 commit contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - bump versions ([`3ffbbb4`](https://github.com/ZetaNumbers/wasm4-rs/commit/3ffbbb4e106ce545fcf0b8a1fa36e40e3384afdc))
</details>

## 0.1.1 (2022-01-17)

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 2 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release wasm4-sys v0.1.1, wasm4-impl v0.1.1, wasm4 v0.1.1 ([`9587707`](https://github.com/ZetaNumbers/wasm4-rs/commit/958770778205fcf22318ffb4a25dc359baa0513a))
    - fix crates' descriptions ([`2bed060`](https://github.com/ZetaNumbers/wasm4-rs/commit/2bed0608fe6d1f95412b53e4b2a100c6d9413898))
    - fix license ([`7e163bd`](https://github.com/ZetaNumbers/wasm4-rs/commit/7e163bdedd898202b4009fd19a79e286592174a0))
</details>

## 0.1.0 (2022-01-14)

### New Features

 - <csr-id-06dc6afedf6ea051c5927fd06f0b7fd84a6bb55b/> add `include_sprites!` macro

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 4 commits contributed to the release.
 - 3 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release wasm4-impl v0.1.0 ([`2031d7b`](https://github.com/ZetaNumbers/wasm4-rs/commit/2031d7b5dfe38b8a5394942e1777811e5c70812b))
    - update changelogs ([`a0f0eb4`](https://github.com/ZetaNumbers/wasm4-rs/commit/a0f0eb4c388e0b91a9edda291aa61f10e3388229))
    - bump versions ([`ac05404`](https://github.com/ZetaNumbers/wasm4-rs/commit/ac05404fc96f0089d40dd55f238da870f683526f))
    - add `include_sprites!` macro ([`06dc6af`](https://github.com/ZetaNumbers/wasm4-rs/commit/06dc6afedf6ea051c5927fd06f0b7fd84a6bb55b))
</details>
